what.attacks.detection.yolo API documentation

# what.attacks.detection.yolo

This module implements several white-box attacks against YOLO object detection model.

## what.attacks.detection.yolo.PCB

- A Man-in-the-Middle Attack against Object Detection Systems.

## what.attacks.detection.yolo.TOG

- Adversarial Objectness Gradient Attacks in Real-time Object Detection Systems.

View Source

     1r'''
     2This module implements several white-box attacks against YOLO object detection model.
     3
     4
     5## what.attacks.detection.yolo.PCB
     6
     7- [A Man-in-the-Middle Attack against Object Detection Systems](https://arxiv.org/abs/2208.07174).
     8
     9## what.attacks.detection.yolo.TOG
    10
    11- [Adversarial Objectness Gradient Attacks in Real-time Object Detection Systems](https://ieeexplore.ieee.org/document/9325397).
    12
    13'''